@@ -75,6 +75,9 @@ public:
 	virtual void setLastPlayersTurn(int theValue) =0;
 	virtual int getLastPlayersTurn() const =0;
 
+        virtual void setLastActionPlayer( unsigned theValue ) =0;
+        virtual unsigned getLastActionPlayer() const =0;
+
 	virtual void setCardsShown(bool theValue) =0;
 	virtual bool getCardsShown() const =0;
 
