@@ -21,8 +21,8 @@
 
 using namespace std;
 
-ClientHand::ClientHand(boost::shared_ptr<EngineFactory> f, GuiInterface *g, BoardInterface *b, PlayerList sl, PlayerList apl, PlayerList rpl, int id, int sP, int dP, int sB,int sC)
-: myFactory(f), myGui(g),  myBoard(b), seatsList(sl), activePlayerList(apl), runningPlayerList(rpl), myID(id), startQuantityPlayers(sP), dealerPosition(dP), currentRound(0),
+ClientHand::ClientHand(boost::shared_ptr<EngineFactory> f, GuiInterface *g, BoardInterface *b, Log *l, PlayerList sl, PlayerList apl, PlayerList rpl, int id, int sP, int dP, int sB,int sC)
+: myFactory(f), myGui(g),  myBoard(b), myLog(l), seatsList(sl), activePlayerList(apl), runningPlayerList(rpl), myID(id), startQuantityPlayers(sP), dealerPosition(dP), currentRound(0),
   smallBlind(sB), startCash(sC), lastPlayersTurn(-1), allInCondition(0),
   cardsShown(false), bettingRoundsPlayed(0)
 {
@@ -296,6 +296,18 @@ ClientHand::getLastPlayersTurn() const
 	return lastPlayersTurn;
 }
 
+void
+ClientHand::setLastActionPlayer (unsigned theValue)
+{
+        lastActionPlayer = theValue;
+}
+
+unsigned
+ClientHand::getLastActionPlayer() const
+{
+         return lastActionPlayer;
+}
+
 void
 ClientHand::setCardsShown(bool theValue)
 {
