@@ -35,8 +35,13 @@ aboutPokerthImpl::aboutPokerthImpl(QWidget *parent, ConfigFile *c)
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 
 	QPalette myPalette = textBrowser_licence->palette();
-	QColor myColor = myPalette.color(QPalette::Window);
-	myPalette.setColor(QPalette::Base, myColor);
+	//--- GUI_800x480
+	myPalette.setColor(QPalette::Base, QColor(0,0,0,0));
+	myPalette.setColor(QPalette::Text, QColor(255,255,255,255));
+	//---
+	// QColor myColor = myPalette.color(QPalette::Window);
+	// myPalette.setColor(QPalette::Base, myColor);
+	//---
 	textBrowser_licence->setPalette(myPalette);
 	textBrowser_2->setPalette(myPalette);
 	textBrowser_3->setPalette(myPalette);
@@ -53,9 +58,13 @@ aboutPokerthImpl::aboutPokerthImpl(QWidget *parent, ConfigFile *c)
 	}
 	
 	
-	label_logo->setPixmap(QPixmap(myAppDataPath+"gfx/gui/misc/logoChip3D.png"));
+        label_logo->setPixmap(QPixmap(":/gfx/logoChip3D.png"));
 
-	label_pokerthVersion->setStyleSheet("QLabel { font-size: 16px; font-weight: bold;}");
+	//--- GUI_800x480 ---
+	label_pokerthVersion->setStyleSheet("QLabel { font-size: 18px; font-weight: bold;}");
+	//---
+	// label_pokerthVersion->setStyleSheet("QLabel { font-size: 16px; font-weight: bold;}");
+	//---
 	label_pokerthVersion->setText(QString(tr("PokerTH %1").arg(POKERTH_BETA_RELEASE_STRING)));
 	this->setWindowTitle(QString(tr("About PokerTH %1").arg(POKERTH_BETA_RELEASE_STRING)));
 
